@@ -25,9 +25,15 @@
 #include "channel.h"
 #include "images.h"
 #include "notificationhandler.h"
+#include "launcherentryhandler.h"
 #include "awaymanager.h"
 #include "konversation_log.h"
+#include "konversation_state.h"
+
+#include <kwindowsystem_version.h>
+#if KWINDOWSYSTEM_VERSION < QT_VERSION_CHECK(5, 91, 0)
 #include "config-konversation.h"
+#endif
 
 #include <KIO/JobUiDelegate>
 #include <KIO/OpenUrlJob>
@@ -39,7 +45,6 @@
 #include <KSharedConfig>
 #include <KStartupInfo>
 #include <KWindowSystem>
-#include <kwindowsystem_version.h>
 
 #include <QRegularExpression>
 #include <QDBusConnection>
@@ -70,6 +75,7 @@ Application::Application(int &argc, char **argv)
     m_sound = nullptr;
     m_dccTransferManager = nullptr;
     m_notificationHandler = nullptr;
+    m_launcherEntryHandler = nullptr;
     m_urlModel = nullptr;
     dbusObject = nullptr;
     identDBus = nullptr;
@@ -85,6 +91,7 @@ Application::~Application()
 
     stashQueueRates();
     Preferences::self()->save(); // FIXME i can't figure out why this isn't in saveOptions --argonel
+    KonversationState::self()->save();
     saveOptions(false);
 
     // Delete m_dccTransferManager here as its destructor depends on the main loop being in tact which it
@@ -269,6 +276,7 @@ QT_WARNING_POP
     }
 
     m_notificationHandler = new Konversation::NotificationHandler(this);
+    m_launcherEntryHandler = new Konversation::LauncherEntryHandler(this);
 
     connect(this, &Application::appearanceChanged, this, &Application::updateProxySettings);
 }
@@ -499,11 +507,7 @@ void Application::readOptions()
             serverGroup->setNotificationsEnabled(cgServerGroup.readEntry("EnableNotifications", true));
             serverGroup->setExpanded(cgServerGroup.readEntry("Expanded", false));
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-            notifyList.insert((*serverGroup).id(), cgServerGroup.readEntry("NotifyList", QString()).split(QLatin1Char(' '), QString::SkipEmptyParts));
-#else
             notifyList.insert((*serverGroup).id(), cgServerGroup.readEntry("NotifyList", QString()).split(QLatin1Char(' '), Qt::SkipEmptyParts));
-#endif
 
             const QStringList serverNames = cgServerGroup.readEntry("ServerList", QStringList());
             for (const QString& serverName : serverNames) {
@@ -643,11 +647,7 @@ void Application::readOptions()
     if (cgDefault.hasKey("Highlight")) // Stay compatible with versions < 0.14
     {
         QString highlight=cgDefault.readEntry("Highlight");
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-        QStringList hiList = highlight.split(QLatin1Char(' '), QString::SkipEmptyParts);
-#else
         QStringList hiList = highlight.split(QLatin1Char(' '), Qt::SkipEmptyParts);
-#endif
 
         for (int hiIndex=0; hiIndex < hiList.count(); hiIndex+=2)
         {
@@ -1370,13 +1370,28 @@ void Application::handleActivate(const QStringList& arguments)
 
     newInstance(m_commandLineParser);
 
+    activateForStartLikeCall();
+}
+
+void Application::handleOpen(const QList<QUrl>& urls)
+{
+    for (const QUrl& url : urls) {
+        getConnectionManager()->connectTo(Konversation::SilentlyReuseConnection, url.toString());
+    }
+    activateForStartLikeCall();
+}
+
+void Application::activateForStartLikeCall()
+{
     mainWindow->show();
+#if KWINDOWSYSTEM_VERSION >= QT_VERSION_CHECK(5, 91, 0)
+    KWindowSystem::updateStartupId(mainWindow->windowHandle());
+#else
 #if HAVE_X11
     if (KWindowSystem::isPlatformX11()) {
         KStartupInfo::setNewStartupId(mainWindow->windowHandle(), QX11Info::nextStartupId());
     } else
 #endif
-#if KWINDOWSYSTEM_VERSION >= QT_VERSION_CHECK(5, 83, 0)
     if (KWindowSystem::isPlatformWayland()) {
         const QString token = qEnvironmentVariable("XDG_ACTIVATION_TOKEN");
         if (!token.isEmpty()) {
@@ -1388,7 +1403,5 @@ void Application::handleActivate(const QStringList& arguments)
     mainWindow->activateAndRaiseWindow();
 }
 
-
-
 // kate: space-indent on; tab-width 4; indent-width 4; mixed-indent off; replace-tabs on;
 // vim: set et sw=4 ts=4 cino=l1,cs,U1:
