@@ -23,8 +23,8 @@
 #include "notificationhandler.h"
 #include "viewcontainer.h"
 #include "konversation_log.h"
+#include "konversation_state.h"
 
-#include <kwidgetsaddons_version.h>
 #include <KAuthorized>
 #include <KPasswordDialog>
 #include <KMessageBox>
@@ -465,11 +465,7 @@ void Channel::textPasted(const QString& text)
 {
     if(m_server)
     {
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-        const QStringList multiline = text.split(QLatin1Char('\n'), QString::SkipEmptyParts);
-#else
         const QStringList multiline = text.split(QLatin1Char('\n'), Qt::SkipEmptyParts);
-#endif
         for (QString line : multiline) {
             QString cChar(Preferences::self()->commandChar());
             // make sure that lines starting with command char get escaped
@@ -808,11 +804,7 @@ void Channel::sendText(const QString& sendLine)
     OutputFilter::replaceAliases(outputAll, this);
 
     // Send all strings, one after another
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    const QStringList outList = outputAll.split(QRegularExpression(QStringLiteral("[\r\n]+")), QString::SkipEmptyParts);
-#else
     const QStringList outList = outputAll.split(QRegularExpression(QStringLiteral("[\r\n]+")), Qt::SkipEmptyParts);
-#endif
     for (const QString& output : outList){
         // encoding stuff is done in Server()
         Konversation::OutputFilterResult result = m_server->getOutputFilter()->parse(m_server->getNickname(), output, getName(), this);
@@ -889,9 +881,7 @@ void Channel::modeButtonClicked(int id, bool on)
         {
             QPointer<KPasswordDialog> dlg = new KPasswordDialog(this);
             dlg->setPrompt(i18n("Channel Password"));
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 84, 0)
             dlg->setRevealPasswordAvailable(KAuthorized::authorize(QStringLiteral("lineedit_reveal_password")));
-#endif
             if (dlg->exec() && !dlg->password().isEmpty())
             {
                 args = dlg->password();
@@ -2054,13 +2044,13 @@ void Channel::showEvent(QShowEvent*)
 
 void Channel::syncSplitters()
 {
-    QList<int> vertSizes = Preferences::self()->topicSplitterSizes();
-    QList<int> horizSizes = Preferences::self()->channelSplitterSizes();
+    QList<int> vertSizes = KonversationState::self()->topicSplitterSizes();
+    QList<int> horizSizes = KonversationState::self()->channelSplitterSizes();
 
     if (vertSizes.isEmpty())
     {
         vertSizes = { m_topicButton->height(), (height() - m_topicButton->height()) };
-        Preferences::self()->setTopicSplitterSizes(vertSizes);
+        KonversationState::self()->setTopicSplitterSizes(vertSizes);
     }
 
     if (horizSizes.isEmpty())
@@ -2069,7 +2059,7 @@ void Channel::syncSplitters()
         // tested with 8pt and 10pt DejaVu Sans and Droid Sans.
         int listWidth = fontMetrics().averageCharWidth() * 17 + 20;
         horizSizes = { (width() - listWidth), listWidth };
-        Preferences::self()->setChannelSplitterSizes(horizSizes);
+        KonversationState::self()->setChannelSplitterSizes(horizSizes);
     }
 
     m_vertSplitter->setSizes(vertSizes);
@@ -2648,16 +2638,16 @@ bool Channel::eventFilter(QObject* watched, QEvent* e)
     {
         if (!topicSplitterHidden && !channelSplitterHidden)
         {
-            Preferences::self()->setChannelSplitterSizes(m_horizSplitter->sizes());
-            Preferences::self()->setTopicSplitterSizes(m_vertSplitter->sizes());
+            KonversationState::self()->setChannelSplitterSizes(m_horizSplitter->sizes());
+            KonversationState::self()->setTopicSplitterSizes(m_vertSplitter->sizes());
         }
         if (!topicSplitterHidden && channelSplitterHidden)
         {
-            Preferences::self()->setTopicSplitterSizes(m_vertSplitter->sizes());
+            KonversationState::self()->setTopicSplitterSizes(m_vertSplitter->sizes());
         }
         if (!channelSplitterHidden && topicSplitterHidden)
         {
-            Preferences::self()->setChannelSplitterSizes(m_horizSplitter->sizes());
+            KonversationState::self()->setChannelSplitterSizes(m_horizSplitter->sizes());
         }
     }
 
